@@ -1,8 +1,8 @@
 ##############################################################################
-#      $URL: http://perlcritic.tigris.org/svn/perlcritic/branches/Perl-Critic-1.073/lib/Perl/Critic/Document.pm $
-#     $Date: 2007-09-15 09:36:06 -0500 (Sat, 15 Sep 2007) $
+#      $URL: http://perlcritic.tigris.org/svn/perlcritic/trunk/Perl-Critic/lib/Perl/Critic/Document.pm $
+#     $Date: 2007-11-11 21:48:21 -0600 (Sun, 11 Nov 2007) $
 #   $Author: clonezone $
-# $Revision: 1908 $
+# $Revision: 2018 $
 ##############################################################################
 
 package Perl::Critic::Document;
@@ -14,7 +14,7 @@ use Scalar::Util qw(weaken);
 
 #-----------------------------------------------------------------------------
 
-our $VERSION = 1.078;
+our $VERSION = '1.080';
 
 #-----------------------------------------------------------------------------
 
@@ -35,6 +35,13 @@ sub new {
 
 #-----------------------------------------------------------------------------
 
+sub ppi_document {
+    my ($self) = @_;
+    return $self->{_doc};
+}
+
+#-----------------------------------------------------------------------------
+
 sub isa {
     my ($self, @args) = @_;
     return $self->SUPER::isa(@args)
@@ -198,6 +205,12 @@ better than we do here?
 
 Create a new instance referencing a PPI::Document instance.
 
+=item $self->ppi_document()
+
+Accessor for the wrapped PPI::Document instance.  Note that altering this
+instance in any way can cause unpredictable failures in Perl::Critic's
+subsequent analysis because some caches may fall out of date.
+
 =item $self->find($wanted)
 
 =item $self->find_first($wanted)
