@@ -1,10 +1,16 @@
+##############################################################################
+#      $URL: http://perlcritic.tigris.org/svn/perlcritic/trunk/Perl-Critic/lib/Perl/Critic/Exception/Configuration/Option.pm $
+#     $Date: 2007-11-11 21:48:21 -0600 (Sun, 11 Nov 2007) $
+#   $Author: clonezone $
+# $Revision: 2018 $
+##############################################################################
+
 package Perl::Critic::Exception::Configuration::Option;
 
-use 5.006001;
 use strict;
 use warnings;
 
-our $VERSION = '1.139_01';
+our $VERSION = '1.080';
 
 #-----------------------------------------------------------------------------
 
@@ -57,23 +63,17 @@ __END__
 
 =head1 NAME
 
-Perl::Critic::Exception::Configuration::Option - A problem with an option in the L<Perl::Critic|Perl::Critic> configuration.
+Perl::Critic::Exception::Configuration::Option - A problem with an option in the L<Perl::Critic> configuration
 
 =head1 DESCRIPTION
 
 A representation of a problem found with an option in the
-configuration of L<Perl::Critic|Perl::Critic>, whether from a
-F<.perlcriticrc>, another profile file, or command line.
+configuration of L<Perl::Critic>, whether from a F<.perlcriticrc>,
+another profile file, or command line.
 
 This is an abstract class.  It should never be instantiated.
 
 
-=head1 INTERFACE SUPPORT
-
-This is considered to be a public class.  Any changes to its interface
-will go through a deprecation cycle.
-
-
 =head1 METHODS
 
 =over
@@ -113,8 +113,8 @@ implement it.
 
 =head1 SEE ALSO
 
-L<Perl::Critic::Exception::Configuration::Option::Global|Perl::Critic::Exception::Configuration::Option::Global>
-L<Perl::Critic::Exception::Configuration::Option::Policy|Perl::Critic::Exception::Configuration::Option::Policy>
+L<Perl::Critic::Exception::Configuration::Option::Global>
+L<Perl::Critic::Exception::Configuration::Option::Policy>
 
 
 =head1 AUTHOR
@@ -123,7 +123,7 @@ Elliot Shank <perl@galumph.com>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2007-2011 Elliot Shank.
+Copyright (c) 2007 Elliot Shank.  All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.  The full text of this license
@@ -138,4 +138,4 @@ can be found in the LICENSE file included with this module.
 #   indent-tabs-mode: nil
 #   c-indentation-style: bsd
 # End:
-# ex: set ts=8 sts=4 sw=4 tw=78 ft=perl expandtab shiftround :
+# ex: set ts=8 sts=4 sw=4 tw=78 ft=perl expandtab :
