@@ -1,10 +1,16 @@
+##############################################################################
+#      $URL: http://perlcritic.tigris.org/svn/perlcritic/trunk/Perl-Critic/lib/Perl/Critic/Exception/Configuration/Option/Global.pm $
+#     $Date: 2007-11-11 21:48:21 -0600 (Sun, 11 Nov 2007) $
+#   $Author: clonezone $
+# $Revision: 2018 $
+##############################################################################
+
 package Perl::Critic::Exception::Configuration::Option::Global;
 
-use 5.006001;
 use strict;
 use warnings;
 
-our $VERSION = '1.139_01';
+our $VERSION = '1.080';
 
 #-----------------------------------------------------------------------------
 
@@ -29,30 +35,24 @@ __END__
 
 =head1 NAME
 
-Perl::Critic::Exception::Configuration::Option::Global - A problem with L<Perl::Critic|Perl::Critic> global configuration.
+Perl::Critic::Exception::Configuration::Option::Global - A problem with L<Perl::Critic> global configuration
 
 =head1 DESCRIPTION
 
 A representation of a problem found with the global configuration of
-L<Perl::Critic|Perl::Critic>, whether from a F<.perlcriticrc>, another
-profile file, or command line.
+L<Perl::Critic>, whether from a F<.perlcriticrc>, another profile
+file, or command line.
 
 This is an abstract class.  It should never be instantiated.
 
 
-=head1 INTERFACE SUPPORT
-
-This is considered to be a public class.  Any changes to its interface
-will go through a deprecation cycle.
-
-
 =head1 AUTHOR
 
 Elliot Shank <perl@galumph.com>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2007-2011 Elliot Shank.
+Copyright (c) 2007 Elliot Shank.  All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.  The full text of this license
@@ -67,4 +67,4 @@ can be found in the LICENSE file included with this module.
 #   indent-tabs-mode: nil
 #   c-indentation-style: bsd
 # End:
-# ex: set ts=8 sts=4 sw=4 tw=78 ft=perl expandtab shiftround :
+# ex: set ts=8 sts=4 sw=4 tw=78 ft=perl expandtab :
