@@ -1,6 +1,12 @@
+##############################################################################
+#      $URL: http://perlcritic.tigris.org/svn/perlcritic/trunk/Perl-Critic/lib/Perl/Critic/Exception/Configuration/Option/Global/ParameterValue.pm $
+#     $Date: 2007-11-11 21:48:21 -0600 (Sun, 11 Nov 2007) $
+#   $Author: clonezone $
+# $Revision: 2018 $
+##############################################################################
+
 package Perl::Critic::Exception::Configuration::Option::Global::ParameterValue;
 
-use 5.006001;
 use strict;
 use warnings;
 
@@ -8,7 +14,7 @@ use Readonly;
 
 use Perl::Critic::Utils qw{ :characters };
 
-our $VERSION = '1.139_01';
+our $VERSION = '1.080';
 
 #-----------------------------------------------------------------------------
 
@@ -62,7 +68,7 @@ __END__
 
 =head1 NAME
 
-Perl::Critic::Exception::Configuration::Option::Global::ParameterValue - A problem with the value of a global parameter.
+Perl::Critic::Exception::Configuration::Option::Global::ParameterValue - A problem with the value of a global parameter
 
 =head1 DESCRIPTION
 
@@ -71,12 +77,6 @@ parameter, whether from a F<.perlcriticrc>, another profile file, or
 command line.
 
 
-=head1 INTERFACE SUPPORT
-
-This is considered to be a public class.  Any changes to its interface
-will go through a deprecation cycle.
-
-
 =head1 CLASS METHODS
 
 =over
@@ -113,7 +113,7 @@ Elliot Shank <perl@galumph.com>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2007-2011 Elliot Shank.
+Copyright (c) 2007 Elliot Shank.  All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.  The full text of this license
@@ -128,4 +128,4 @@ can be found in the LICENSE file included with this module.
 #   indent-tabs-mode: nil
 #   c-indentation-style: bsd
 # End:
-# ex: set ts=8 sts=4 sw=4 tw=78 ft=perl expandtab shiftround :
+# ex: set ts=8 sts=4 sw=4 tw=78 ft=perl expandtab :
