@@ -1,12 +1,18 @@
+##############################################################################
+#      $URL: http://perlcritic.tigris.org/svn/perlcritic/trunk/Perl-Critic/lib/Perl/Critic/Exception/Fatal/Generic.pm $
+#     $Date: 2007-11-11 21:48:21 -0600 (Sun, 11 Nov 2007) $
+#   $Author: clonezone $
+# $Revision: 2018 $
+##############################################################################
+
 package Perl::Critic::Exception::Fatal::Generic;
 
-use 5.006001;
 use strict;
 use warnings;
 
 use Readonly;
 
-our $VERSION = '1.139_01';
+our $VERSION = '1.080';
 
 #-----------------------------------------------------------------------------
 
@@ -37,19 +43,13 @@ __END__
 
 =head1 NAME
 
-Perl::Critic::Exception::Fatal::Generic - A problem for which there is no specialized information.
+Perl::Critic::Exception::Fatal::Generic - A problem for which there is no specialized information
 
 =head1 DESCRIPTION
 
 A general problem, e.g. I/O errors and problems that may or not be bugs.
 
 
-=head1 INTERFACE SUPPORT
-
-This is considered to be a public class.  Any changes to its interface
-will go through a deprecation cycle.
-
-
 =head1 METHODS
 
 Only inherited ones.
@@ -61,7 +61,7 @@ Elliot Shank <perl@galumph.com>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2007-2011 Elliot Shank.
+Copyright (c) 2007 Elliot Shank.  All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.  The full text of this license
@@ -76,4 +76,4 @@ can be found in the LICENSE file included with this module.
 #   indent-tabs-mode: nil
 #   c-indentation-style: bsd
 # End:
-# ex: set ts=8 sts=4 sw=4 tw=78 ft=perl expandtab shiftround :
+# ex: set ts=8 sts=4 sw=4 tw=78 ft=perl expandtab :
