@@ -1,43 +1,35 @@
+##############################################################################
+#      $URL: http://perlcritic.tigris.org/svn/perlcritic/trunk/Perl-Critic/lib/Perl/Critic/Policy/RegularExpressions/ProhibitComplexRegexes.pm $
+#     $Date: 2007-11-11 21:48:21 -0600 (Sun, 11 Nov 2007) $
+#   $Author: clonezone $
+# $Revision: 2018 $
+##############################################################################
+
 package Perl::Critic::Policy::RegularExpressions::ProhibitComplexRegexes;
 
-use 5.006001;
 use strict;
 use warnings;
-
-use Carp;
-use English qw(-no_match_vars);
-use List::Util qw{ min };
 use Readonly;
 
-use Perl::Critic::Utils qw{ :booleans :severities };
+use English qw(-no_match_vars);
+use Carp;
 
+use Perl::Critic::Utils qw{ :booleans :severities };
+use Perl::Critic::Utils::PPIRegexp qw{ parse_regexp get_match_string get_modifiers };
 use base 'Perl::Critic::Policy';
 
-our $VERSION = '1.139_01';
+our $VERSION = '1.080';
 
 #-----------------------------------------------------------------------------
 
 Readonly::Scalar my $DESC => q{Split long regexps into smaller qr// chunks};
 Readonly::Scalar my $EXPL => [261];
 
-Readonly::Scalar my $MAX_LITERAL_LENGTH => 7;
-Readonly::Scalar my $MAX_VARIABLE_LENGTH => 4;
+Readonly::Scalar my $DEFAULT_MAX_COMPLEXITY => 60;
 
 #-----------------------------------------------------------------------------
 
-sub supported_parameters {
-    return (
-        {
-            name            => 'max_characters',
-            description     =>
-                'The maximum number of characters to allow in a regular expression.',
-            default_string  => '60',
-            behavior        => 'integer',
-            integer_minimum => 1,
-        },
-    );
-}
-
+sub supported_parameters { return qw(max_characters)         }
 sub default_severity     { return $SEVERITY_MEDIUM           }
 sub default_themes       { return qw( core pbp maintenance ) }
 sub applies_to           { return qw(PPI::Token::Regexp::Match
@@ -46,48 +38,43 @@ sub applies_to           { return qw(PPI::Token::Regexp::Match
 
 #-----------------------------------------------------------------------------
 
+sub initialize_if_enabled {
+    my ($self, $config) = @_;
+
+    #Set configuration if defined
+    $self->{_max_characters} =
+            defined $config->{max_characters}
+        &&  $config->{max_characters} =~ m/(\d+)/xms
+        &&  $1 > 0
+            ? $1 : $DEFAULT_MAX_COMPLEXITY;
+
+    return $TRUE;
+}
+
+#-----------------------------------------------------------------------------
+
 sub violates {
-    my ( $self, $elem, $document ) = @_;
+    my ( $self, $elem, undef ) = @_;
 
     # Optimization: if its short enough now, parsing won't make it longer
-    return if $self->{_max_characters} >= length $elem->get_match_string();
+    return if $self->{_max_characters} >= length get_match_string($elem);
 
-    my $re = $document->ppix_regexp_from_element( $elem )
-        or return;  # Abort on syntax error.
-    $re->failures()
-        and return; # Abort if parse errors found.
-    my $qr = $re->regular_expression()
-        or return;  # Abort if no regular expression.
+    # If it has an "x" flag, it might be shorter after comment and whitespace removal
+    my %modifiers = get_modifiers($elem);
+    if ($modifiers{x}) {
+       my $re = parse_regexp($elem);
+       return if !$re; # syntax error, abort
+       my $qr = $re->visual;
 
-    my $length = 0;
-    # We use map { $_->tokens() } qr->children() rather than just
-    # $qr->tokens() because we are not interested in the delimiters.
-    foreach my $token ( map { $_->tokens() } $qr->children() ) {
+       # HACK: Remove any (?xism:...) wrapper we may have added in the parse process...
+       $qr =~ s/\A [(][?][xism]+(?:-[xism]+)?: (.*) [)] \z/$1/xms;
 
-        # Do not count whitespace or comments
-        $token->significant() or next;
-
-        if ( $token->isa( 'PPIx::Regexp::Token::Interpolation' ) ) {
-
-            # Do not penalize long variable names
-            $length += min( $MAX_VARIABLE_LENGTH, length $token->content() );
-
-        } elsif ( $token->isa( 'PPIx::Regexp::Token::Literal' ) ) {
-
-            # Do not penalize long literals like \p{...}
-            $length += min( $MAX_LITERAL_LENGTH, length $token->content() );
-
-        } else {
-
-            # Take everything else at face value
-            $length += length $token->content();
-
-        }
+       # Hack: don't count long \p{...} expressions against us so badly
+       $qr =~ s/\\[pP][{]\w+[}]/\\p{...}/gmx;
 
+       return if $self->{_max_characters} >= length $qr;
     }
 
-    return if $self->{_max_characters} >= $length;
-
     return $self->violation( $DESC, $EXPL, $elem );
 }
 
@@ -103,14 +90,7 @@ __END__
 
 =head1 NAME
 
-Perl::Critic::Policy::RegularExpressions::ProhibitComplexRegexes - Split long regexps into smaller C<qr//> chunks.
-
-
-=head1 AFFILIATION
-
-This Policy is part of the core L<Perl::Critic|Perl::Critic>
-distribution.
-
+Perl::Critic::Policy::RegularExpressions::ProhibitComplexRegexes
 
 =head1 DESCRIPTION
 
@@ -121,17 +101,10 @@ characters, where C<N> is a configurable value that defaults to 60.
 If the regexp uses the C<x> flag, then the length is computed after
 parsing out any comments or whitespace.
 
-Unfortunately the use of descriptive (and therefore longish) variable
-names can cause regexps to be in violation of this policy, so
-interpolated variables are counted as 4 characters no matter how long
-their names actually are.
-
-
 =head1 CASE STUDY
 
-As an example, look at the regexp used to match email addresses in
-L<Email::Valid::Loose|Email::Valid::Loose> (tweaked lightly to wrap
-for POD)
+As an example, look at the regexp used to match email
+addresses in L<Email::Valid::Loose> (tweaked lightly to wrap for POD)
 
     (?x-ism:(?:[^(\040)<>@,;:".\\\[\]\000-\037\x80-\xff]+(?![^(\040)<>@,;:".\\\[\]
     \000-\037\x80-\xff])|"[^\\\x80-\xff\n\015"]*(?:\\[^\x80-\xff][^\\\x80-\xff\n\015
@@ -178,7 +151,6 @@ times.  Furthermore, it's much easier to compare the second version
 against the source BNF grammar in RFC 822 to judge whether the
 implementation is sound even before running tests.
 
-
 =head1 CONFIGURATION
 
 This policy allows regexps up to C<N> characters long, where C<N>
@@ -186,24 +158,20 @@ defaults to 60.  You can override this to set it to a different number
 with the C<max_characters> setting.  To do this, put entries in a
 F<.perlcriticrc> file like this:
 
-    [RegularExpressions::ProhibitComplexRegexes]
-    max_characters = 40
-
+  [RegularExpressions::ProhibitComplexRegexes]
+  max_characters = 40
 
 =head1 CREDITS
 
-Initial development of this policy was supported by a grant from the
-Perl Foundation.
-
+Initial development of this policy was supported by a grant from the Perl Foundation.
 
 =head1 AUTHOR
 
 Chris Dolan <cdolan@cpan.org>
 
-
 =head1 COPYRIGHT
 
-Copyright (c) 2007-2011 Chris Dolan.  Many rights reserved.
+Copyright (c) 2007 Chris Dolan.  Many rights reserved.
 
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.  The full text of this license
@@ -218,4 +186,4 @@ can be found in the LICENSE file included with this module
 #   indent-tabs-mode: nil
 #   c-indentation-style: bsd
 # End:
-# ex: set ts=8 sts=4 sw=4 tw=78 ft=perl expandtab shiftround :
+# ex: set ts=8 sts=4 sw=4 tw=78 ft=perl expandtab :
