@@ -1,18 +1,25 @@
+##############################################################################
+#      $URL: http://perlcritic.tigris.org/svn/perlcritic/trunk/Perl-Critic/lib/Perl/Critic/Policy/RegularExpressions/ProhibitEnumeratedClasses.pm $
+#     $Date: 2007-11-11 21:48:21 -0600 (Sun, 11 Nov 2007) $
+#   $Author: clonezone $
+# $Revision: 2018 $
+##############################################################################
+
 package Perl::Critic::Policy::RegularExpressions::ProhibitEnumeratedClasses;
 
-use 5.006001;
 use strict;
 use warnings;
+use Readonly;
 
 use English qw(-no_match_vars);
 use List::MoreUtils qw(all);
-use Readonly;
+use Carp qw(carp);
 
 use Perl::Critic::Utils qw{ :booleans :severities hashify };
-
+use Perl::Critic::Utils::PPIRegexp qw{ ppiify parse_regexp get_modifiers };
 use base 'Perl::Critic::Policy';
 
-our $VERSION = '1.139_01';
+our $VERSION = '1.080';
 
 #-----------------------------------------------------------------------------
 
@@ -20,11 +27,11 @@ Readonly::Scalar my $DESC => q{Use named character classes};
 Readonly::Scalar my $EXPL => [248];
 
 Readonly::Array my @PATTERNS => (  # order matters: most to least specific
-   [q{ },'\\t','\\r','\\n']      => ['\\s', '\\S'],
-   ['A-Z','a-z','0-9','_']       => ['\\w', '\\W'], # RT 69322
-   ['A-Z','a-z']                 => ['[[:alpha:]]','[[:^alpha:]]'],
-   ['A-Z']                       => ['[[:upper:]]','[[:^upper:]]'],
-   ['a-z']                       => ['[[:lower:]]','[[:^lower:]]'],
+   [q{ },'\\t','\\r','\\n']      => ['\\s', '\\S'],  ##no critic (Interpolation)
+   ['A-Z','a-z','_']             => ['\\w', '\\W'],
+   ['A-Z','a-z']                 => ['\\p{IsAlphabetic}','\\P{IsAlphabetic}'],
+   ['A-Z']                       => ['\\p{IsUppercase}','\\P{IsUppercase}'],
+   ['a-z']                       => ['\\p{IsLowercase}','\\P{IsLowercase}'],
    ['0-9']                       => ['\\d','\\D'],
    ['\w']                        => [undef, '\\W'],
    ['\s']                        => [undef, '\\S'],
@@ -41,24 +48,22 @@ sub applies_to           { return qw(PPI::Token::Regexp::Match
 
 #-----------------------------------------------------------------------------
 
-
 sub violates {
-    my ( $self, $elem, $document ) = @_;
+    my ( $self, $elem, undef ) = @_;
 
     # optimization: don't bother parsing the regexp if there are no character classes
     return if $elem !~ m/\[/xms;
 
-    my $re = $document->ppix_regexp_from_element( $elem ) or return;
-    $re->failures() and return;
+    my $re = ppiify(parse_regexp($elem));
+    return if !$re;
 
-    my $anyofs = $re->find( 'PPIx::Regexp::Structure::CharClass' )
-        or return;
-    foreach my $anyof ( @{ $anyofs } ) {
-        my $violation;
-        $violation = $self->_get_character_class_violations( $elem, $anyof )
-            and return $violation;
+    # Must pass a sub to find() because our node classes don't start with PPI::
+    my $anyofs = $re->find(sub {$_[1]->isa('Perl::Critic::PPIRegexp::anyof')});
+    return if !$anyofs;
+    for my $anyof (@{$anyofs}) {
+        my $violation = $self->_get_character_class_violations($elem, $anyof);
+        return $violation if $violation;
     }
-
     return;  # OK
 }
 
@@ -66,13 +71,26 @@ sub _get_character_class_violations {
     my ($self, $elem, $anyof) = @_;
 
     my %elements;
-    foreach my $element ( $anyof->children() ) {
-        $elements{ _fixup( $element ) } = 1;
+    for my $element ($anyof->children) {
+        if ($element->isa('Perl::Critic::PPIRegexp::exact')) {
+            my @tokens = split m/(\\.[^\\]*)/xms, $element->content;
+            for my $token (map { split m/\A (\\[nrf])/xms, _fixup($_); } @tokens) {  ##no critic(Comma) ## TODO: FALSE POSITIVE
+                $elements{$token} = 1;
+            }
+        } elsif ($element->isa('Perl::Critic::PPIRegexp::anyof_char') ||
+                 $element->isa('Perl::Critic::PPIRegexp::anyof_range') ||
+                 $element->isa('Perl::Critic::PPIRegexp::anyof_class')) {
+            for my $token (split m/\A (\\[nrf])/xms, _fixup($element->content)) {
+                $elements{$token} = 1;
+            }
+        } else {
+            # no known way to get to this branch; just for forward compatibility
+            carp 'Unexpected type inside a character class: ' . (ref $element) . " '$element'";
+        }
     }
-
     for (my $i = 0; $i < @PATTERNS; $i += 2) {  ##no critic (CStyleForLoop)
         if (all { exists $elements{$_} } @{$PATTERNS[$i]}) {
-            my $neg = $anyof->negated();
+            my $neg = $anyof->re->neg;
             my $improvement = $PATTERNS[$i + 1]->[$neg ? 1 : 0];
             next if !defined $improvement;
 
@@ -90,24 +108,28 @@ sub _get_character_class_violations {
     return;  # OK
 }
 
-Readonly::Hash my %ORDINALS => (
-    ord "\n"    => '\\n',
-    ord "\f"    => '\\f',
-    ord "\r"    => '\\r',
-    ord q< >    => q< >,
+Readonly::Hash my %HEX => (  # Note: this is ASCII specific!
+   '0a' => '\\n',  ##no critic (Interpolation)
+   '0c' => '\\f',  ##no critic (Interpolation)
+   '0d' => '\\r',  ##no critic (Interpolation)
+   '20' => q{ },
 );
-
 sub _fixup {
-    my ( $element ) = @_;
-    if ( $element->isa( 'PPIx::Regexp::Token::Literal' ) ) {
-        my $ord = $element->ordinal();
-        exists $ORDINALS{$ord} and return $ORDINALS{$ord};
-        return $element->content();
-    } elsif ( $element->isa( 'PPIx::Regexp::Node' ) ) {
-        return join q{}, map{ _fixup( $_ ) } $element->elements();
-    } else {
-        return $element->content();
-    }
+   my ($chars) = @_;
+
+   # \x0a -> \x{0a}
+   $chars =~ s/\A \\x([\da-fA-F]{2})/\\x{$1}/gxms;
+
+   # '\ ' -> q{ }
+   $chars =~ s/\A \\[ ]/ /gxms;
+
+   # \012 -> \x{0a}
+   $chars =~ s/\A \\0([0-7]{2})/'\\x{'.(sprintf "%02x", oct $1).'}'/egxms;
+
+   # \x{0a} -> \n
+   $chars =~ s/\A (\\x [{] ([\da-fA-F]+) [}] ) /exists $HEX{$2} ? $HEX{$2} : $1/egxms;
+
+   return $chars;
 }
 
 1;
@@ -120,14 +142,7 @@ __END__
 
 =head1 NAME
 
-Perl::Critic::Policy::RegularExpressions::ProhibitEnumeratedClasses - Use named character classes instead of explicit character lists.
-
-
-=head1 AFFILIATION
-
-This Policy is part of the core L<Perl::Critic|Perl::Critic>
-distribution.
-
+Perl::Critic::Policy::RegularExpressions::ProhibitEnumeratedClasses
 
 =head1 DESCRIPTION
 
@@ -137,7 +152,7 @@ then disable it now or you may see some false violations.
 On the other hand many of us are working in a multilingual world with
 an extended character set, probably Unicode.  In that world, patterns
 like C<m/[A-Z]/> can be a source of bugs when you really meant
-C<m/\p{IsUpper}/>.  This policy catches a selection of possible
+C<m/\p{Uppercase}/>.  This policy catches a selection of possible
 incorrect character class usage.
 
 Specifically, the patterns are:
@@ -146,13 +161,13 @@ B<C<[\t\r\n\f\ ]>> vs. B<C<\s>>
 
 B<C<[\t\r\n\ ]>> vs. B<C<\s>>   (because many people forget C<\f>)
 
-B<C<[A-Za-z0-9_]>> vs. B<C<\w>>
+B<C<[A-Za-z_]>> vs. B<C<\w>>
 
 B<C<[A-Za-z]>> vs. B<C<\p{IsAlphabetic}>>
 
-B<C<[A-Z]>> vs. B<C<\p{IsUpper}>>
+B<C<[A-Z]>> vs. B<C<\p{IsUppercase}>>
 
-B<C<[a-z]>> vs. B<C<\p{IsLower}>>
+B<C<[a-z]>> vs. B<C<\p{IsLowercase}>>
 
 B<C<[0-9]>> vs. B<C<\d>>
 
@@ -160,26 +175,17 @@ B<C<[^\w]>> vs. B<C<\W>>
 
 B<C<[^\s]>> vs. B<C<\S>>
 
-
-=head1 CONFIGURATION
-
-This Policy is not configurable except for the standard options.
-
-
 =head1 CREDITS
 
-Initial development of this policy was supported by a grant from the
-Perl Foundation.
-
+Initial development of this policy was supported by a grant from the Perl Foundation.
 
 =head1 AUTHOR
 
 Chris Dolan <cdolan@cpan.org>
 
-
 =head1 COPYRIGHT
 
-Copyright (c) 2007-2011 Chris Dolan.  Many rights reserved.
+Copyright (c) 2007 Chris Dolan.  Many rights reserved.
 
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.  The full text of this license
@@ -194,4 +200,4 @@ can be found in the LICENSE file included with this module
 #   indent-tabs-mode: nil
 #   c-indentation-style: bsd
 # End:
-# ex: set ts=8 sts=4 sw=4 tw=78 ft=perl expandtab shiftround :
+# ex: set ts=8 sts=4 sw=4 tw=78 ft=perl expandtab :
