@@ -1,6 +1,12 @@
+##############################################################################
+#      $URL: http://perlcritic.tigris.org/svn/perlcritic/trunk/Perl-Critic/lib/Perl/Critic/Policy/RegularExpressions/RequireBracesForMultiline.pm $
+#     $Date: 2007-11-11 21:48:21 -0600 (Sun, 11 Nov 2007) $
+#   $Author: clonezone $
+# $Revision: 2018 $
+##############################################################################
+
 package Perl::Critic::Policy::RegularExpressions::RequireBracesForMultiline;
 
-use 5.006001;
 use strict;
 use warnings;
 use Readonly;
@@ -9,31 +15,19 @@ use English qw(-no_match_vars);
 use Carp;
 
 use Perl::Critic::Utils qw{ :booleans :severities };
-
+use Perl::Critic::Utils::PPIRegexp qw{ get_match_string get_delimiters };
 use base 'Perl::Critic::Policy';
 
-our $VERSION = '1.139_01';
+our $VERSION = '1.080';
 
 #-----------------------------------------------------------------------------
 
-Readonly::Scalar my $DESC => q<Use '{' and '}' to delimit multi-line regexps>;
+Readonly::Scalar my $DESC => q{Use '{' and '}' to delimit multi-line regexps};
 Readonly::Scalar my $EXPL => [242];
 
-Readonly::Array my @EXTRA_BRACKETS => qw{ () [] <> };
-
 #-----------------------------------------------------------------------------
 
-sub supported_parameters {
-    return (
-        {
-            name               => 'allow_all_brackets',
-            description        =>
-                q[In addition to allowing '{}', allow '()', '[]', and '{}'.],
-            behavior           => 'boolean',
-        },
-    );
-}
-
+sub supported_parameters { return qw()                    }
 sub default_severity     { return $SEVERITY_LOWEST        }
 sub default_themes       { return qw( core pbp cosmetic ) }
 sub applies_to           { return qw(PPI::Token::Regexp::Match
@@ -42,29 +36,14 @@ sub applies_to           { return qw(PPI::Token::Regexp::Match
 
 #-----------------------------------------------------------------------------
 
-sub initialize_if_enabled {
-    my ( $self, $config ) = @_;
-
-    my %delimiters = ( q<{}> => 1 );
-    if ( $self->{_allow_all_brackets} ) {
-        @delimiters{ @EXTRA_BRACKETS } = (1) x @EXTRA_BRACKETS;
-    }
-
-    $self->{_allowed_delimiters} = \%delimiters;
-
-    return $TRUE;
-}
-
-#-----------------------------------------------------------------------------
-
 sub violates {
     my ( $self, $elem, undef ) = @_;
 
-    my $re = $elem->get_match_string();
+    my $re = get_match_string($elem);
     return if $re !~ m/\n/xms;
 
-    my ($match_delim) = $elem->get_delimiters();
-    return if $self->{_allowed_delimiters}{$match_delim};
+    my ($match_delim) = get_delimiters($elem);
+    return if '{}' eq $match_delim;
 
     return $self->violation( $DESC, $EXPL, $elem );
 }
@@ -79,14 +58,7 @@ __END__
 
 =head1 NAME
 
-Perl::Critic::Policy::RegularExpressions::RequireBracesForMultiline - Use C<{> and C<}> to delimit multi-line regexps.
-
-
-=head1 AFFILIATION
-
-This Policy is part of the core L<Perl::Critic|Perl::Critic>
-distribution.
-
+Perl::Critic::Policy::RegularExpressions::RequireBracesForMultiline
 
 =head1 DESCRIPTION
 
@@ -114,31 +86,19 @@ vs.
      }
      {link=$1, text=$2}xms;
 
-Is that an improvement?  Marginally, but yes.  The curly braces lead
-the eye better.
-
-
-=head1 CONFIGURATION
-
-There is one option for this policy, C<allow_all_brackets>.  If this
-is true, then, in addition to allowing C<{}>, the other matched pairs
-of C<()>, C<[]>, and C<< <> >> are allowed.
-
+Is that an improvement?  Marginally, but yes.  The curly braces lead the eye better.
 
 =head1 CREDITS
 
-Initial development of this policy was supported by a grant from the
-Perl Foundation.
-
+Initial development of this policy was supported by a grant from the Perl Foundation.
 
 =head1 AUTHOR
 
 Chris Dolan <cdolan@cpan.org>
 
-
 =head1 COPYRIGHT
 
-Copyright (c) 2007-2011 Chris Dolan.  Many rights reserved.
+Copyright (c) 2007 Chris Dolan.  Many rights reserved.
 
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.  The full text of this license
@@ -153,4 +113,4 @@ can be found in the LICENSE file included with this module
 #   indent-tabs-mode: nil
 #   c-indentation-style: bsd
 # End:
-# ex: set ts=8 sts=4 sw=4 tw=78 ft=perl expandtab shiftround :
+# ex: set ts=8 sts=4 sw=4 tw=78 ft=perl expandtab :
