@@ -1,36 +1,31 @@
 ##############################################################################
-#      $URL: http://perlcritic.tigris.org/svn/perlcritic/tags/Perl-Critic-1.105_001/lib/Perl/Critic/Utils/PPIRegexp.pm $
-#     $Date: 2010-01-16 11:48:41 -0800 (Sat, 16 Jan 2010) $
-#   $Author: thaljef $
-# $Revision: 3748 $
+#      $URL: http://perlcritic.tigris.org/svn/perlcritic/trunk/Perl-Critic/lib/Perl/Critic/Utils/PPIRegexp.pm $
+#     $Date: 2007-11-11 21:48:21 -0600 (Sun, 11 Nov 2007) $
+#   $Author: clonezone $
+# $Revision: 2018 $
 ##############################################################################
 
 package Perl::Critic::Utils::PPIRegexp;
 
-use 5.006001;
 use strict;
 use warnings;
-
 use English qw(-no_match_vars);
-use Readonly;
-use Carp qw(croak);
-
 use PPI::Node;
+use Carp qw(croak);
 
 use base 'Exporter';
 
-our $VERSION = '1.105_01';
+our $VERSION = '1.080';
 
 #-----------------------------------------------------------------------------
 
 our @EXPORT_OK = qw(
-    parse_regexp
-    get_match_string
-    get_substitute_string
-    get_modifiers
-    get_delimiters
-    ppiify
-    regexp_interpolates
+    &parse_regexp
+    &get_match_string
+    &get_substitute_string
+    &get_modifiers
+    &get_delimiters
+    &ppiify
 );
 
 our %EXPORT_TAGS = (
@@ -42,7 +37,8 @@ our %EXPORT_TAGS = (
 sub parse_regexp {
     my ($elem) = @_;
 
-    eval { require Regexp::Parser; } or return;
+    eval { require Regexp::Parser; };
+    return if $EVAL_ERROR;
 
     my $re = get_match_string($elem);
     return if !defined $re;
@@ -104,7 +100,7 @@ sub get_delimiters {
         # hack: pull them out ourselves
         # limitation: this regexp fails on s{foo}<bar>
         my $operator = defined $elem->{operator} ? $elem->{operator} : q{};
-        @delimiters = join q{}, $elem =~ m/\A $operator (.).*?(.) (?:[xmsocgie]*) \z/xms;
+        @delimiters = join q{}, $elem =~ m/\A $operator (.).*?(.) (?:[xmsocgie]*) \z/mx;
     } else {
         @delimiters = ($elem->{sections}->[0]->{type});
         if ($elem->{sections}->[1]) {
@@ -124,7 +120,7 @@ sub get_delimiters {
 
     sub _get_ppi_package {
         my ($src_class, $re_node) = @_;
-        (my $dest_class = $src_class) =~ s/\A Regexp::Parser::/Perl::Critic::PPIRegexp::/xms;
+        (my $dest_class = $src_class) =~ s/\A Regexp::Parser::/Perl::Critic::PPIRegexp::/mx;
         if (!$seen{$src_class}) {
             $seen{$src_class} = 1;
             croak 'Regexp node which is not in the Regexp::Parser namespace'
@@ -132,19 +128,17 @@ sub get_delimiters {
             my $src_isa_name = $src_class . '::ISA';
             my $dest_isa_name = $dest_class . '::ISA';
             my @isa;
-            for my $isa (eval "\@$src_isa_name") { ## no critic (StringyEval)
+            for my $isa (eval "\@$src_isa_name") { ##no critic(Eval)
                 my $dest_isa = _get_ppi_package($isa, $re_node);
                 push @isa, $dest_isa;
             }
-            eval "\@$dest_isa_name = qw(@isa)"; ## no critic (Eval)
+            eval "\@$dest_isa_name = qw(@isa)"; ##no critic(Eval)
             croak $EVAL_ERROR if $EVAL_ERROR;
         }
         return $dest_class;
     }
 }
 
-Readonly::Scalar my $NO_DEPTH_USED  => -1;
-
 sub ppiify {
     my ($re) = @_;
     return if !$re;
@@ -154,7 +148,7 @@ sub ppiify {
     my $ppire = PPI::Node->new;
     my @stack = ($ppire);
     my $iter = $re->walker;
-    my $last_depth = $NO_DEPTH_USED;
+    my $last_depth = -1;
     while (my ($node, $depth) = $iter->()) {
         if ($last_depth > $depth) { # -> parent
             # walker() creates pseudo-closing nodes for reasons I don't understand
@@ -170,7 +164,7 @@ sub ppiify {
             } else {            # -> child
                 push @stack, $ppinode;
             }
-            $stack[-2]->add_element($ppinode); ## no critic qw(MagicNumbers)
+            $stack[-2]->add_element($ppinode);
         }
         $last_depth = $depth;
     }
@@ -178,7 +172,7 @@ sub ppiify {
 }
 
 {
-    package   ## no critic (ProhibitMultiplePackages, NamingConventions::Capitalization)  # hide from PAUSE
+    package   ##no critic (Package)  # hide from PAUSE
       Perl::Critic::PPIRegexp::__object__;
     use base 'PPI::Node';
 
@@ -204,14 +198,6 @@ sub ppiify {
     }
 }
 
-#-----------------------------------------------------------------------------
-
-sub regexp_interpolates {
-    my ( $elem ) = @_;
-    my @delim = get_delimiters( $elem ) or return;
-    return q{'} ne substr $delim[0], 0, 1;
-}
-
 1;
 
 __END__
@@ -226,7 +212,6 @@ __END__
 
 Perl::Critic::Utils::PPIRegexp - Utility functions for dealing with PPI regexp tokens.
 
-
 =head1 SYNOPSIS
 
    use Perl::Critic::Utils::PPIRegexp qw(:all);
@@ -235,24 +220,15 @@ Perl::Critic::Utils::PPIRegexp - Utility functions for dealing with PPI regexp t
    my $elem = $doc->find('PPI::Token::Regexp::Match')->[0];
    print get_match_string($elem);  # yields 'foo'
 
-
 =head1 DESCRIPTION
 
 As of PPI v1.1xx, the PPI regexp token classes
-(L<PPI::Token::Regexp::Match|PPI::Token::Regexp::Match>,
-L<PPI::Token::Regexp::Substitute|PPI::Token::Regexp::Substitute> and
-L<PPI::Token::QuoteLike::Regexp|PPI::Token::QuoteLike::Regexp>) has a
-very weak interface, so it is necessary to dig into internals to learn
-anything useful.  This package contains subroutines to encapsulate
-that excess intimacy.  If future versions of PPI gain better
-accessors, this package will start using those.
-
-
-=head1 INTERFACE SUPPORT
-
-This is considered to be a public module.  Any changes to its
-interface will go through a deprecation cycle.
-
+(L<PPI::Token::Regexp::Match>, L<PPI::Token::Regexp::Substitute> and
+L<PPI::Token::QuoteLike::Regexp>) has a very weak interface, so it is
+necessary to dig into internals to learn anything useful.  This
+package contains subroutines to encapsulate that excess intimacy.  If
+future versions of PPI gain better accessors, this package will start
+using those.
 
 =head1 IMPORTABLE SUBS
 
@@ -260,96 +236,76 @@ interface will go through a deprecation cycle.
 
 =item C<parse_regexp( $token )>
 
-Parse the regexp token with L<Regexp::Parser|Regexp::Parser>.  If that
-module is not available or if there is a parse error, returns undef.
-If a parse success, returns a Regexp::Parser instance that can be used
-to walk the regexp object model.
+Parse the regexp token with L<Regexp::Parser>.  If that module is not
+available or if there is a parse error, returns undef.  If a parse success,
+returns a Regexp::Parser instance that can be used to walk the regexp object
+model.
 
-CAVEAT: This method pays special attention to the C<x> modifier to the
-regexp.  If present, we wrap the regexp string in C<(?x:...)> to
-ensure a proper parse.  This does change the object model though.
-
-Someday if PPI gets native Regexp support, this method may become
-deprecated.
+CAVEAT: This method pays special attention to the C<x> modifier to the regexp.
+If present, we wrap the regexp string in C<(?x:...)> to ensure a proper parse.
+This does change the object model though.
 
+Someday if PPI gets native Regexp support, this method may become deprecated.
 
 =item C<ppiify( $regexp )>
 
-Given a L<Regexp::Parser|Regexp::Parser> instance (perhaps as returned
-from C<parse_regexp>) convert it to a tree of L<PPI::Node|PPI::Node>
-instances.  This is useful because PPI has a more familiar and
-powerful programming model than the Regexp::Parser object tree.
-
-Someday if PPI gets native Regexp support, this method may become a
-no-op.
+Given a L<Regexp::Parser> instance (perhaps as returned from C<parse_regexp>)
+convert it to a tree of L<PPI::Node> instances.  This is useful because PPI
+has a more familiar and powerful programming model than the Regexp::Parser
+object tree.
 
+Someday if PPI gets native Regexp support, this method may become a no-op.
 
 =item C<get_match_string( $token )>
 
 Returns the match portion of the regexp or undef if the specified
 token is not a regexp.  Examples:
 
-    m/foo/;         # yields 'foo'
-    s/foo/bar/;     # yields 'foo'
-    / \A a \z /xms; # yields ' \\A a \\z '
-    qr{baz};        # yields 'baz'
-
+  m/foo/;         # yields 'foo'
+  s/foo/bar/;     # yields 'foo'
+  / \A a \z /xms; # yields ' \\A a \\z '
+  qr{baz};        # yields 'baz'
 
 =item C<get_substitute_string( $token )>
 
 Returns the substitution portion of a search-and-replace regexp or
 undef if the specified token is not a valid regexp.  Examples:
 
-    m/foo/;         # yields undef
-    s/foo/bar/;     # yields 'bar'
-
+  m/foo/;         # yields undef
+  s/foo/bar/;     # yields 'bar'
 
 =item C<get_modifiers( $token )>
 
 Returns a hash containing booleans for the modifiers of the regexp, or
 undef if the token is not a regexp.
 
-    /foo/xms;  # yields (m => 1, s => 1, x => 1)
-    s/foo//;   # yields ()
-    qr/foo/i;  # yields (i => 1)
-
+  /foo/xms;  # yields (m => 1, s => 1, x => 1)
+  s/foo//;   # yields ()
+  qr/foo/i;  # yields (i => 1)
 
 =item C<get_delimiters( $token )>
 
 Returns one (or two for a substitution regexp) two-character strings
-indicating the delimiters of the regexp, or an empty list if the token
-is not a regular expression token.  For example:
+indicating the delimiters of the regexp, or an empty list if the token is not
+a regular expression token.  For example:
 
-    m/foo/;      # yields ('//')
-    m#foo#;      # yields ('##')
-    m<foo>;      # yields ('<>')
-    s/foo/bar/;  # yields ('//', '//')
-    s{foo}{bar}; # yields ('{}', '{}')
-    s{foo}/bar/; # yields ('{}', '//')   valid, but yuck!
-    qr/foo/;     # yields ('//')
-
-=item C<regexp_interpolates( $token )>
-
-Returns true if the given regexp interpolates, false if it does not, or undef
-if the status can not be determined. The determining factor is whether or not
-the first delimiting character (as returned by C<get_delimiters>) is a single
-quote. For example:
-
-    m/foo/;     # yields true
-    qr{foo};    # yields true
-    m'foo';     # yields false
+   m/foo/;      # yields ('//')
+   m#foo#;      # yields ('##')
+   m<foo>;      # yields ('<>')
+   s/foo/bar/;  # yields ('//', '//')
+   s{foo}{bar}; # yields ('{}', '{}')
+   s{foo}/bar/; # yields ('{}', '//')   valid, but yuck!
+   qr/foo/;     # yields ('//')
 
 =back
 
-
 =head1 AUTHOR
 
 Chris Dolan <cdolan@cpan.org>
 
-
 =head1 COPYRIGHT
 
-Copyright (c) 2007-2010 Chris Dolan.  Many rights reserved.
+Copyright (c) 2007 Chris Dolan.  Many rights reserved.
 
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.  The full text of this license
@@ -364,4 +320,4 @@ can be found in the LICENSE file included with this module.
 #   indent-tabs-mode: nil
 #   c-indentation-style: bsd
 # End:
-# ex: set ts=8 sts=4 sw=4 tw=78 ft=perl expandtab shiftround :
+# ex: set ts=8 sts=4 sw=4 tw=78 ft=perl expandtab :
